Skip to contents

This package can be used to download IMR Biotic database and to place it into a duckdb database, providing access to all of the institute’s Biotic data from R.

Details

The database can be downloaded and compiled using the compileDatabase function.

Author

Maintainer: Mikko Vihtakari mikko.vihtakari@hi.no

Authors:

Other contributors:

  • Institute of Marine Research [copyright holder]