Skip to contents

Food and Agriculture Organization Major Fishing Area 27 (i.e. ICES region) fishing area polygons. The polygons are not cut with land as opposed to the areas distributed on the ICES website (see BioticExplorerServer:::prepareICESareas). This makes the polygons smaller and consequent calculations quicker. Use this dataset instead of the function.

Usage

icesAreas

Format

st_polygon in decimal degrees (EPSG:4326).