Skip to contents

Downloads and compiles the cruise series reference list from the IMR API. The result is bundled as cruiseSeries package data. Run this function and save with usethis::use_data(cruiseSeries, overwrite = TRUE) to refresh the bundled data.

Usage

prepareCruiseSeriesList()

Value

A data.table with columns cruise, platformname, startyear, cruiseseriescode, and name.

Author

Ibrahim Umar, Mikko Vihtakari